package com.engidea.comm;

import java.util.*;

/*
  WinJcom is a native interface to serial ports in java.
  Copyright 2007 by Damiano Bolla, Jcomm@engidea.com

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/

/**
 * If you ever want to know what was the previous state of something just save it in your code.
 * If you ever want to know what is the current state of something use one of the
 * isXXXX() The whole idea is Keep It Simple !!!
 */
public class SerialPortEvent extends EventObject
  {
  private static final long serialVersionUID = 1L;
  
  public static final int DATA_AVAILABLE = 1;
  public static final int OUTPUT_BUFFER_EMPTY = 2;
  public static final int CTS = 3;
  public static final int DSR = 4;
  public static final int RI  = 5;
  public static final int CD  = 6;
  public static final int OE  = 7;
  public static final int PE  = 8;
  public static final int FE  = 9;
  public static final int BI  = 10;

  private int eventType;

  public SerialPortEvent( SerialPort srcport, int eventtype )
    {
    super(srcport);
    this.eventType = eventtype;
    }

  public int getEventType()
    {
    return eventType;
    }
    
  public String getEventTypeString ()
    {
    switch ( eventType )  
      {
      case DATA_AVAILABLE: return "RxData";
      case OUTPUT_BUFFER_EMPTY: return "TxEmpty";
      case CTS: return "CTS";
      case DSR: return "DSR";
      case RI:  return "RI";
      case CD:  return "CD";
      case OE:  return "OE";
      case PE:  return "PE";
      case FE:  return "FE";
      case BI:  return "BI";
      default:  return "Unknown";
      }
    }
    
  public String toString()
    {
    return super.toString()+" "+getEventTypeString();
    }
  }
